<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/tiled/aboutdialog.ui" line="+14"/>
        <source>About Tiled</source>
        <translation>关于Tiled</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../src/tiled/aboutdialog.cpp" line="+32"/>
        <source>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+2&quot;&gt;&lt;b&gt;Tiled Map Editor&lt;/b&gt;&lt;/font&gt;&lt;br&gt;&lt;i&gt;Version %1&lt;/i&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Copyright 2008-2010 Thorbj&amp;oslash;rn Lindeijer&lt;br&gt;(see the AUTHORS file for a full list of contributors)&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;You may modify and redistribute this program under the terms of the GPL (version 2 or later). A copy of the GPL is contained in the &apos;COPYING&apos; file distributed with Tiled.&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;
</source>
        <translation>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+2&quot;&gt;&lt;b&gt;Tiled地图编辑器&lt;/b&gt;&lt;/font&gt;&lt;br&gt;&lt;i&gt;版本 %1&lt;/i&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Copyright 2008-2010 Thorbj&amp;oslash;rn Lindeijer&lt;br&gt;(查看AUTHORS文件获取全部贡献者名单列表)&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;你可以基于GPL(V2或更新版本)修改、重发布此应用程序.GPL的一份拷贝被包含在&apos;COPYING&apos;文件中并随Tiled一起发布.&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;
</translation>
    </message>
</context>
<context>
    <name>CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.ui" line="+14"/>
        <source>Properties</source>
        <translation>属性</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>&amp;Save map before executing</source>
        <translation>执行前保存地图(&amp;S)</translation>
    </message>
    <message>
        <source>Save map before executing</source>
        <translation type="obsolete">执行前保存地图</translation>
    </message>
</context>
<context>
    <name>Droidcraft::DroidcraftPlugin</name>
    <message>
        <location filename="../src/plugins/droidcraft/droidcraftplugin.cpp" line="+56"/>
        <source>This is not a valid Droidcraft map file!</source>
        <translation>无效的Droidcraft地图文件！</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>The map needs to have exactly one tile layer!</source>
        <translation>地图必须至少有一个图层！</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>The layer must have a size of 48 x 48 tiles!</source>
        <translation>图层至少得有一个48x48的块!</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Could not open file for writing.</source>
        <translation>文件不可写</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Droidcraft map files (*.dat)</source>
        <translation>Droidcraft map 文件 (*.dat)</translation>
    </message>
</context>
<context>
    <name>Lua::LuaPlugin</name>
    <message>
        <location filename="../src/plugins/lua/luaplugin.cpp" line="+46"/>
        <source>Could not open file for writing.</source>
        <translation>文件不可写</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Lua files (*.lua)</source>
        <translation>Lua 文件 (*.lua)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.ui" line="+17"/>
        <source>Tiled</source>
        <translation>Tiled</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;File</source>
        <translation>文件(&amp;F)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Recent Files</source>
        <translation>最近的文件(&amp;R)</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Edit</source>
        <translation>编辑(&amp;E)</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Map</source>
        <translation>地图(&amp;M)</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;View</source>
        <translation>视图(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation type="obsolete">图层(&amp;L)</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Main Toolbar</source>
        <translation>主工具栏</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Open...</source>
        <translation>打开(&amp;O)...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Quit</source>
        <translation>退出(&amp;Q)</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>&amp;Copy</source>
        <translation>复制(&amp;C)</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Paste</source>
        <translation>粘贴(&amp;P)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;About Tiled</source>
        <translation>关于 Tiled(&amp;A)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>About Qt</source>
        <translation>关于 Qt</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Resize Map...</source>
        <translation>调整地图大小(&amp;R)...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map &amp;Properties...</source>
        <translation>地图属性(&amp;P)...</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>AutoMap</source>
        <translation>自动映射</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Show &amp;Grid</source>
        <translation>显示网格(&amp;G)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Save &amp;As...</source>
        <translation>另存为(&amp;A)...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;New...</source>
        <translation>新文件(&amp;N)...</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Save As &amp;Image...</source>
        <translation>另存为图片(&amp;I)...</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>&amp;Export As...</source>
        <translation>导出为(&amp;E)...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Add External Tileset...</source>
        <translation>添加外部图块(&amp;A)...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Snap to Grid</source>
        <translation>对齐网格(&amp;S)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>C&amp;lose All</source>
        <translation>关闭全部(&amp;l)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+Shift+W</source>
        <translation></translation>
    </message>
    <message>
        <source>Move Layer &amp;Up</source>
        <translation type="obsolete">上移图层(&amp;U)</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation type="obsolete">Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Move Layer Dow&amp;n</source>
        <translation type="obsolete">下移图层(&amp;N)</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation type="obsolete">Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="obsolete">选择全部(&amp;A)</translation>
    </message>
    <message>
        <source>Select &amp;None</source>
        <translation type="obsolete">取消选择(&amp;N)</translation>
    </message>
    <message>
        <source>New...</source>
        <translation type="obsolete">新文件...</translation>
    </message>
    <message>
        <location line="-113"/>
        <source>New &amp;Tileset...</source>
        <translation>新图块(&amp;T)...</translation>
    </message>
    <message>
        <source>&amp;Remove Layer</source>
        <translation type="obsolete">删除图层(&amp;R)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Close</source>
        <translation>关闭(&amp;C)</translation>
    </message>
    <message>
        <source>Add &amp;Tile Layer...</source>
        <translation type="obsolete">添加图层(&amp;T)...</translation>
    </message>
    <message>
        <source>Add &amp;Object Layer...</source>
        <translation type="obsolete">添加对象层(&amp;O)...</translation>
    </message>
    <message>
        <source>&amp;Duplicate Layer</source>
        <translation type="obsolete">复制图层(&amp;D)</translation>
    </message>
    <message>
        <source>Ctrl+Shift+D</source>
        <translation type="obsolete">Ctrl+Shift+D</translation>
    </message>
    <message>
        <source>Layer &amp;Properties...</source>
        <translation type="obsolete">图层设置(&amp;P)...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom In</source>
        <translation>放大</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom Out</source>
        <translation>缩小</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Normal Size</source>
        <translation>正常</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>Save As Image...</source>
        <translation type="obsolete">另存为图片...</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Cu&amp;t</source>
        <translation>剪切(&amp;T)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Offset Map...</source>
        <translation>挪动地图(&amp;O)...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Offsets everything in a layer</source>
        <translation>挪动图层内一切内容</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Pre&amp;ferences...</source>
        <translation>参数(&amp;f)...</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Clear Recent Files</source>
        <translation>清除最近的文件</translation>
    </message>
</context>
<context>
    <name>MapObjectItem</name>
    <message>
        <source>&amp;Duplicate</source>
        <translation type="obsolete">复制(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">删除(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Properties...</source>
        <translation type="obsolete">属性(&amp;P)...</translation>
    </message>
    <message>
        <source>&amp;Duplicate Object</source>
        <translation type="obsolete">复制对象(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Remove Object</source>
        <translation type="obsolete">删除对象(&amp;R)</translation>
    </message>
    <message>
        <source>Object &amp;Properties...</source>
        <translation type="obsolete">对象属性(&amp;P)...</translation>
    </message>
</context>
<context>
    <name>MapReader</name>
    <message>
        <location filename="../src/libtiled/mapreader.cpp" line="+130"/>
        <source>Not a map file.</source>
        <translation>该地图的文件不可用.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Not a tileset file.</source>
        <translation>不是一个图块集文件.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>%3

Line %1, column %2</source>
        <translation>%3

行 %1, 位置 %2</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File not found: %1</source>
        <translation>文件没有找到: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unable to read file: %1</source>
        <translation>无法读取文件: %1</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Unsupported map orientation: &quot;%1&quot;</source>
        <translation>地图不支持旋转: &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
        <translation>无效的图块属性&apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Error while loading tileset &apos;%1&apos;: %2</source>
        <translation>载入图块错误 &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Invalid tile ID: %1</source>
        <translation>无效块ID: %1</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Error loading tileset image:
&apos;%1&apos;</source>
        <translation>载入图块图像出错:
&apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Too many &lt;tile&gt; elements</source>
        <translation>&lt;块&gt; 元素过多</translation>
    </message>
    <message>
        <location line="+11"/>
        <location line="+72"/>
        <location line="+39"/>
        <location line="+90"/>
        <source>Invalid tile: %1</source>
        <translation>无效块: %1</translation>
    </message>
    <message>
        <location line="-181"/>
        <source>Unknown encoding: %1</source>
        <translation>未知编码: %1</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Compression method &apos;%1&apos; not supported</source>
        <translation>不支持压缩方式&apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+39"/>
        <source>Corrupt layer data for layer &apos;%1&apos;</source>
        <translation>图层 &apos;%1&apos; 数据已损坏</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
        <translation>无法解析块在（%1，%2层）&apos;%3&apos;</translation>
    </message>
    <message>
        <source>Invalid global tile id (less than 0): %1</source>
        <translation type="obsolete">无效的全局块id(小于0): %1</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile used but no tilesets specified</source>
        <translation>没有指定图块</translation>
    </message>
    <message>
        <location filename="../src/libtiled/mapwriter.cpp" line="+101"/>
        <source>Could not open file for writing.</source>
        <translation>无法打开写文件.</translation>
    </message>
</context>
<context>
    <name>NewImageLayerDialog</name>
    <message>
        <location filename="../src/tiled/newimagelayerdialog.ui" line="+14"/>
        <source>New Tileset</source>
        <translation>新图块集</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Image layer</source>
        <translation>图像图层</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Name:</source>
        <translation>名称(&amp;N):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Image:</source>
        <translation>图像:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Browse...</source>
        <translation>浏览(&amp;B)...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Use transparent color:</source>
        <translation>使用透明色:</translation>
    </message>
</context>
<context>
    <name>NewMapDialog</name>
    <message>
        <location filename="../src/tiled/newmapdialog.ui" line="+14"/>
        <source>New Map</source>
        <translation>新地图</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map size</source>
        <translation>地图大小</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+55"/>
        <source>Width:</source>
        <translation>宽度:</translation>
    </message>
    <message>
        <location line="-32"/>
        <location line="+55"/>
        <source>Height:</source>
        <translation>高度:</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Tile size</source>
        <translation>块大小</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Map</source>
        <translation>地图</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Orientation:</source>
        <translation>地图方向:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Orthogonal</source>
        <translation>正常</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Isometric</source>
        <translation>45度</translation>
    </message>
</context>
<context>
    <name>NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.ui" line="+6"/>
        <source>New Tileset</source>
        <translation>新图块</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tileset</source>
        <translation>图块</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Name:</source>
        <translation>名称(&amp;N):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Image:</source>
        <translation>图像:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Browse...</source>
        <translation>浏览(&amp;B)...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Use transparent color:</source>
        <translation>设置透明度:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Tiles</source>
        <translation>块</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tile width:</source>
        <translation>块宽度:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Margin:</source>
        <translation>边距:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile height:</source>
        <translation>块高度:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spacing:</source>
        <translation>间距:</translation>
    </message>
</context>
<context>
    <name>ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.ui" line="+26"/>
        <source>Form</source>
        <translation>表单</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Name:</source>
        <translation>名称:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Type:</source>
        <translation>类型:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>宽度:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Height:</source>
        <translation>高度:</translation>
    </message>
</context>
<context>
    <name>OffsetMapDialog</name>
    <message>
        <location filename="../src/tiled/offsetmapdialog.ui" line="+17"/>
        <source>Offset Map</source>
        <translation>挪动地图</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Offset Contents of Map</source>
        <translation>挪动地图的内容</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location line="+23"/>
        <location line="+43"/>
        <source>Wrap</source>
        <translation>延伸</translation>
    </message>
    <message>
        <location line="-36"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Layers:</source>
        <translation>目标层:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>All Visible Layers</source>
        <translation>所有可见图层</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>All Layers</source>
        <translation>全部图层</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Selected Layer</source>
        <translation>选择图层</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Bounds:</source>
        <translation>范围:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Whole Map</source>
        <translation>整个地图</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Current Selection</source>
        <translation>当前选择</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.ui" line="+14"/>
        <source>Preferences</source>
        <translation>设置</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Saving and Loading</source>
        <translation>保存并加载</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Store tile layer data as:</source>
        <translation>另存为数据层(&amp;S):</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>XML</source>
        <translation>XML</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (uncompressed)</source>
        <translation>Base64 (zlib压缩)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (gzip compressed)</source>
        <translation>Base64 (gzip压缩)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (zlib compressed)</source>
        <translation>Base64 (zlib压缩)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>CSV</source>
        <translation>CSV</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Reload tileset images when they change</source>
        <translation>图块的图像改变时重新加载(&amp;R)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Not enabled by default since a reference to an external DTD is known to cause problems with some XML parsers.</source>
        <translation>Not enabled by default since a reference to an external DTD is known to cause problems with some XML parsers.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Include &amp;DTD reference in saved maps</source>
        <translation>保存的地图包括&amp;DTD(&amp;D)</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Interface</source>
        <translation>界面</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Language:</source>
        <translation>语言(&amp;L):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Hardware &amp;accelerated drawing (OpenGL)</source>
        <translation>使用OpenGL硬件加速绘图(&amp;A)</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.ui" line="+14"/>
        <source>Properties</source>
        <translation>属性</translation>
    </message>
</context>
<context>
    <name>ResizeDialog</name>
    <message>
        <location filename="../src/tiled/resizedialog.ui" line="+14"/>
        <source>Resize</source>
        <translation>调整大小</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>宽度:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>高度:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Offset</source>
        <translation>挪动</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
</context>
<context>
    <name>SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.ui" line="+14"/>
        <source>Save As Image</source>
        <translation>另存为图片</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Name:</source>
        <translation>名称:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Browse...</source>
        <translation>浏览(&amp;B)...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Only include &amp;visible layers</source>
        <translation>仅可见图层(&amp;v)</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Use current &amp;zoom level</source>
        <translation>当前缩放级别(&amp;z)</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Draw tile grid</source>
        <translation>绘制网格(&amp;D)</translation>
    </message>
</context>
<context>
    <name>Tengine::TenginePlugin</name>
    <message>
        <location filename="../src/plugins/tengine/tengineplugin.cpp" line="+50"/>
        <source>Could not open file for writing.</source>
        <translation>无法对文件进行读写.</translation>
    </message>
    <message>
        <location line="+243"/>
        <source>T-Engine4 map files (*.lua)</source>
        <translation>T-Engine4 地图文件 (*.lua)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AbstractObjectTool</name>
    <message numerus="yes">
        <location filename="../src/tiled/abstractobjecttool.cpp" line="+134"/>
        <location line="+54"/>
        <source>Duplicate %n Object(s)</source>
        <translation>
            <numerusform><byte value="x1d"/>复制<byte value="x1d"/>%n个对象</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-53"/>
        <location line="+71"/>
        <source>Remove %n Object(s)</source>
        <translation>
            <numerusform>移除%n个对象</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-62"/>
        <location line="+72"/>
        <source>Move %n Object(s) to Layer</source>
        <translation>
            <numerusform>移动%n个对象到层</numerusform>
        </translation>
    </message>
    <message>
        <location line="-62"/>
        <source>Object &amp;Properties...</source>
        <translation>对象属性(&amp;P)...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutoMapper</name>
    <message>
        <location filename="../src/tiled/automap.cpp" line="+116"/>
        <source>Multiple layers %1 found!</source>
        <translation>多个图层 %1 找到!</translation>
    </message>
    <message>
        <location line="+110"/>
        <source>No ruleRegions layer found!</source>
        <translation></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No set layers found!</source>
        <translation></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No ruleSet layer found!</source>
        <translation></translation>
    </message>
    <message>
        <location line="+212"/>
        <source>Tile</source>
        <translation>块</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutomaticMappingManager</name>
    <message>
        <location line="+497"/>
        <source>No set layer found!</source>
        <translation></translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Apply AutoMap rules</source>
        <translation></translation>
    </message>
    <message>
        <location line="+18"/>
        <source>No rules file found at:
%1</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Error opening rules file:
%1</source>
        <translation>打开规则文件错误:
%1</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>File not found:
%1</source>
        <translation>文件未找到:
%1</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Opening rules map failed:
%1</source>
        <translation>打开规则地图失败:%1</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::BucketFillTool</name>
    <message>
        <location filename="../src/tiled/bucketfilltool.cpp" line="+39"/>
        <location line="+133"/>
        <source>Bucket Fill Tool</source>
        <translation>填充</translation>
    </message>
    <message>
        <location line="-130"/>
        <location line="+131"/>
        <source>F</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandButton</name>
    <message>
        <location filename="../src/tiled/commandbutton.cpp" line="+39"/>
        <source>Execute Command</source>
        <translation>执行命令</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Error Executing Command</source>
        <translation>执行命令出错</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>You do not have any commands setup.</source>
        <translation>没有设置任何命令.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Edit commands...</source>
        <translation>编辑命令...</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Edit Commands...</source>
        <translation>编辑命令...</translation>
    </message>
    <message>
        <source>There was an error running the command</source>
        <translation type="obsolete">运行命令出错</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDataModel</name>
    <message>
        <location filename="../src/tiled/commanddatamodel.cpp" line="+60"/>
        <source>Open in text editor</source>
        <translation>在文件编辑器中打开</translation>
    </message>
    <message>
        <location line="+92"/>
        <location line="+67"/>
        <source>&lt;new command&gt;</source>
        <translation>&lt;新<byte value="x1c"/> 命令&gt;</translation>
    </message>
    <message>
        <location line="-59"/>
        <source>Set a name for this command</source>
        <translation>设置命令名称</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Set the shell command to execute</source>
        <translation>设置要执行的<byte value="x1c"/>SHELL命令</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Show or hide this command in the command list</source>
        <translation>在命令列表中显示或隐蔽该<byte value="x1c"/>命令</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Add a new command</source>
        <translation>增加一个新命令</translation>
    </message>
    <message>
        <location line="+101"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Command</source>
        <translation>命令</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Enable</source>
        <translation>可用</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Move Up</source>
        <translation>上移</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move Down</source>
        <translation>下移</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Execute</source>
        <translation>执行</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Execute in Terminal</source>
        <translation>在终端中执行</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <location line="+84"/>
        <source>%1 (copy)</source>
        <translation>%1 (复制)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>New command</source>
        <translation>新命令</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.cpp" line="+40"/>
        <source>Edit Commands</source>
        <translation>编辑命令</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandProcess</name>
    <message>
        <location filename="../src/tiled/command.cpp" line="+122"/>
        <source>Unable to create/open %1</source>
        <translation>不能创建/打开%1</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Unable to add executable permissions to %1</source>
        <translation>不能给%1增加可执行权限</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>The command failed to start.</source>
        <translation>命令无法启动.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>The command crashed.</source>
        <translation>命令崩溃.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>The command timed out.</source>
        <translation>命令超时.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>An unknown error occurred.</source>
        <translation>未知的错误发生.</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Error Executing %1</source>
        <translation>执行错误%1</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CreateObjectTool</name>
    <message>
        <location filename="../src/tiled/createobjecttool.cpp" line="+42"/>
        <location line="+100"/>
        <source>O</source>
        <translation></translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Insert Objects</source>
        <translation>插入对象</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Insert Tile Objects</source>
        <translation>插入图块对象</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>T</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::Eraser</name>
    <message>
        <location filename="../src/tiled/eraser.cpp" line="+34"/>
        <location line="+36"/>
        <source>Eraser</source>
        <translation>橡皮</translation>
    </message>
    <message>
        <location line="-33"/>
        <location line="+34"/>
        <source>E</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ImageLayerPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+60"/>
        <source>Image Layer</source>
        <translation>图像图层</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Browse...</source>
        <translation>浏览...</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Image:</source>
        <translation>图像:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Transparent color:</source>
        <translation>透明色:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Layer Image</source>
        <translation>图层图像:</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerDock</name>
    <message>
        <location filename="../src/tiled/layerdock.cpp" line="+179"/>
        <source>Layers</source>
        <translation>图层</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Opacity:</source>
        <translation>透明度:</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerModel</name>
    <message>
        <location filename="../src/tiled/layermodel.cpp" line="+122"/>
        <source>Layer</source>
        <translation>图层</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerView</name>
    <message>
        <source>Properties...</source>
        <translation type="obsolete">属性...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.cpp" line="+134"/>
        <location line="+8"/>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <location line="-7"/>
        <location line="+6"/>
        <source>Redo</source>
        <translation>恢复</translation>
    </message>
    <message>
        <source>Error while opening map</source>
        <translation type="obsolete">打开地图时出错</translation>
    </message>
    <message>
        <location line="+418"/>
        <source>Open Map</source>
        <translation>打开地图</translation>
    </message>
    <message>
        <location line="-13"/>
        <location line="+76"/>
        <source>Tiled map files (*.tmx)</source>
        <translation>Tiled 地图文件 (*.tmx)</translation>
    </message>
    <message>
        <source>Error while saving map</source>
        <translation type="obsolete">保存地图时出错</translation>
    </message>
    <message>
        <location line="-451"/>
        <source>Ctrl+=</source>
        <translation></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>+</source>
        <translation></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location line="+22"/>
        <location line="+1047"/>
        <source>&amp;Layer</source>
        <translation>图层(&amp;L)</translation>
    </message>
    <message>
        <location line="-910"/>
        <source>Ctrl+PgUp</source>
        <translation></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Ctrl+PgDown</source>
        <translation></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>X</source>
        <translation></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Y</source>
        <translation></translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Error Opening Map</source>
        <translation>打开地图错误</translation>
    </message>
    <message>
        <location line="+73"/>
        <location line="+135"/>
        <source>All Files (*)</source>
        <translation>全部文件 (*)</translation>
    </message>
    <message>
        <location line="-94"/>
        <location line="+141"/>
        <source>Error Saving Map</source>
        <translation>保存地图出错</translation>
    </message>
    <message>
        <location line="-108"/>
        <source>untitled.tmx</source>
        <translation>未命名.tmx</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Unsaved Changes</source>
        <translation>未保存修改</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>There are unsaved changes. Do you want to save now?</source>
        <translation>修改未保存，你需要保存吗?</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Export As...</source>
        <translation>导出为...</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Unknown File Format</source>
        <translation>未知的文件格式</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The given filename does not have any known file extension.</source>
        <translation>未知的文件扩展名.</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Paste Objects</source>
        <translation>粘贴对象</translation>
    </message>
    <message>
        <location line="+370"/>
        <source>[*]%1 - Tiled</source>
        <translation></translation>
    </message>
    <message>
        <source>Add Tilesets</source>
        <translation type="obsolete">添加图块</translation>
    </message>
    <message>
        <location line="-291"/>
        <source>Add External Tileset</source>
        <translation>添加外部图块</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation>Tiled 图块文件 (*.tsx)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Error Reading Tileset</source>
        <translation>读取图块错误</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Map</source>
        <translation>地图</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Automatic Mapping</source>
        <translation>自动映射</translation>
    </message>
    <message>
        <location line="+120"/>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
    <message>
        <source>Add Tile Layer</source>
        <translation type="obsolete">添加块层</translation>
    </message>
    <message>
        <source>Add Object Layer</source>
        <translation type="obsolete">添加对象层</translation>
    </message>
    <message>
        <source>Layer name:</source>
        <translation type="obsolete">图层名称:</translation>
    </message>
    <message>
        <source>New Layer</source>
        <translation type="obsolete">新图层</translation>
    </message>
    <message>
        <source>%1[*] - Tiled</source>
        <translation type="obsolete">%1[*] - Tiled</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocument</name>
    <message>
        <location filename="../src/tiled/mapdocument.cpp" line="+133"/>
        <source>untitled.tmx</source>
        <translation>untitled.tmx</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Resize Map</source>
        <translation>调整大小地图</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Offset Map</source>
        <translation>挪动地图</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile Layer %1</source>
        <translation>块层 %1</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Object Layer %1</source>
        <translation>对象层 %1</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Copy of %1</source>
        <translation>复制 %1</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Duplicate Layer</source>
        <translation>复制图层</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Merge Layer Down</source>
        <translation>向下合并图层</translation>
    </message>
    <message>
        <location line="+138"/>
        <source>Tile</source>
        <translation>图块</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Tileset Changes</source>
        <translation>图块集修改</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocumentActionHandler</name>
    <message>
        <location filename="../src/tiled/mapdocumentactionhandler.cpp" line="+126"/>
        <source>Select &amp;All</source>
        <translation>选择全部(&amp;A)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Select &amp;None</source>
        <translation>选择取消(&amp;N)</translation>
    </message>
    <message>
        <location line="-81"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Add &amp;Tile Layer...</source>
        <translation type="obsolete">添加块层(&amp;T)...</translation>
    </message>
    <message>
        <source>Add &amp;Object Layer...</source>
        <translation type="obsolete">添加对象层(&amp;O)...</translation>
    </message>
    <message>
        <location line="+87"/>
        <source>&amp;Duplicate Layer</source>
        <translation>复制图层(&amp;D)</translation>
    </message>
    <message>
        <location line="-79"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Shift+D</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>PgUp</source>
        <translation></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>PgDown</source>
        <translation></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+Shift+H</source>
        <translation></translation>
    </message>
    <message>
        <location line="+48"/>
        <source>&amp;Crop to Selection</source>
        <translatorcomment>这个不是很确定意思</translatorcomment>
        <translation>剪辑选择</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Add &amp;Tile Layer</source>
        <translation>添加图层(&amp;T)...</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Add &amp;Object Layer</source>
        <translation>添加对象层(&amp;O)...</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Merge Layer Down</source>
        <translation>向下合并图层(&amp;M)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Remove Layer</source>
        <translation>删除图层(&amp;R)</translation>
    </message>
    <message>
        <source>Move Layer &amp;Up</source>
        <translation type="obsolete">上移图层(&amp;U)</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Move Layer Dow&amp;n</source>
        <translation type="obsolete">下移图层(&amp;n)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Select Pre&amp;vious Layer</source>
        <translation>选择上一个图层(&amp;Y)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Select &amp;Next Layer</source>
        <translation>选择下一个图层(&amp;N)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>R&amp;aise Layer</source>
        <translation>前置图层(&amp;A)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Lower Layer</source>
        <translation>后置图层(&amp;L)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show/&amp;Hide all Other Layers</source>
        <translation>显示/隐藏所有其它图层(&amp;H)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer &amp;Properties...</source>
        <translation>设置(&amp;P)...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewMapDialog</name>
    <message>
        <location filename="../src/tiled/newmapdialog.cpp" line="+81"/>
        <source>Tile Layer 1</source>
        <translation>块层 1</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.cpp" line="+123"/>
        <location line="+7"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Failed to load tileset image &apos;%1&apos;.</source>
        <translation>无法载入图块图像%1.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No tiles found in the tileset image when using the given tile size, margin and spacing!</source>
        <translation>在图块图像中使用给定的块大小、边界和间距没有发现图块!</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tileset Image</source>
        <translation>图块图像</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectGroupPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+43"/>
        <source>Object Layer</source>
        <translation>对象层</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>颜色:</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.cpp" line="+41"/>
        <source>Object</source>
        <translation>对象</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">名称:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="obsolete">类型:</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Change Object</source>
        <translation>修改对象</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectSelectionTool</name>
    <message>
        <location filename="../src/tiled/objectselectiontool.cpp" line="+98"/>
        <location line="+110"/>
        <source>Select Objects</source>
        <translation>选择对象</translation>
    </message>
    <message>
        <location line="-108"/>
        <location line="+109"/>
        <source>S</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <source>Duplicate %n Object(s)</source>
        <translation type="obsolete">
            <numerusform><byte value="x1d"/>复制<byte value="x1d"/>%n个对象</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Remove %n Object(s)</source>
        <translation type="obsolete">
            <numerusform>移除%n个对象</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Move %n Object(s) to Layer</source>
        <translation type="obsolete">
            <numerusform>移动%n个对象到层</numerusform>
        </translation>
    </message>
    <message>
        <source>Object &amp;Properties...</source>
        <translation type="obsolete">对象属性(&amp;P)...</translation>
    </message>
    <message numerus="yes">
        <location line="+117"/>
        <source>Move %n Object(s)</source>
        <translation>
            <numerusform>移动%n个对象</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.cpp" line="+56"/>
        <location line="+23"/>
        <source>System default</source>
        <translation>系统默认</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.cpp" line="+69"/>
        <source>%1 Properties</source>
        <translation>%1 属性</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Layer</source>
        <translation>图层</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesModel</name>
    <message>
        <location filename="../src/tiled/propertiesmodel.cpp" line="+51"/>
        <source>&lt;new property&gt;</source>
        <translation>&lt;新的属性&gt;</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Value</source>
        <translation>值</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.cpp" line="+111"/>
        <source>Save as Image</source>
        <translation>保存为图片</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1已经存在.
你要替换它吗?</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Image</source>
        <translation>图像</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SelectionTool</name>
    <message>
        <location filename="../src/tiled/selectiontool.cpp" line="+34"/>
        <location line="+81"/>
        <source>Rectangular Select</source>
        <translation>选择范围</translation>
    </message>
    <message>
        <location line="-78"/>
        <location line="+79"/>
        <source>R</source>
        <translation></translation>
    </message>
    <message>
        <location line="-56"/>
        <source>%1, %2 - Rectangle: (%3 x %4)</source>
        <translation>%1, %2 - 矩形: (%3 x %4)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::StampBrush</name>
    <message>
        <location filename="../src/tiled/stampbrush.cpp" line="+38"/>
        <location line="+281"/>
        <source>Stamp Brush</source>
        <translation>图章刷</translation>
    </message>
    <message>
        <location line="-278"/>
        <location line="+279"/>
        <source>B</source>
        <translation>B</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetDock</name>
    <message>
        <location filename="../src/tiled/tilesetdock.cpp" line="+279"/>
        <source>Remove Tileset</source>
        <translation>删除图块集</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The tileset &quot;%1&quot; is still in use by the map!</source>
        <translation>图块 “%1”仍然在地图使用!</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Remove this tileset and all references to the tiles in this tileset?</source>
        <translation>为了消除这种图块，你确定要删除所有使用块的部分?</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Tilesets</source>
        <translation>图块</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetView</name>
    <message>
        <source>Properties...</source>
        <translation type="obsolete">属性...</translation>
    </message>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="+213"/>
        <source>Tile &amp;Properties...</source>
        <translation>图块属性(&amp;P)...</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Export Tileset As...</source>
        <translation>导出图块为(&amp;E)...</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Import Tileset</source>
        <translation>导入图块(&amp;I)</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show &amp;Grid</source>
        <translation>显示网格(&amp;G)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Tile</source>
        <translation>图块</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Export Tileset</source>
        <translation>导出图块</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation>Tiled 图块文件(*.tsx)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ToolManager</name>
    <message>
        <location filename="../src/tiled/toolmanager.cpp" line="+88"/>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::UndoDock</name>
    <message>
        <location filename="../src/tiled/undodock.cpp" line="+64"/>
        <source>History</source>
        <translation>历史</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&lt;empty&gt;</source>
        <translation>&lt;空白&gt;</translation>
    </message>
</context>
<context>
    <name>Tmw::TmwPlugin</name>
    <message>
        <location filename="../src/plugins/tmw/tmwplugin.cpp" line="+47"/>
        <source>Multiple collision layers found!</source>
        <translation>有多个碰撞层!</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>No collision layer found!</source>
        <translation>没有发现碰撞层!</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Could not open file for writing.</source>
        <translation>无法对文件进行读写.</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>TMW-eAthena collision files (*.wlk)</source>
        <translation>TMW-eAthena 碰撞文件 (*.wlk)</translation>
    </message>
    <message>
        <source>TMW-eAthena collision files 2 (*.wlk2)</source>
        <translation type="obsolete">TMW-eAthena 碰撞文件 2 (*.wlk2)</translation>
    </message>
</context>
<context>
    <name>TmxMapReader</name>
    <message>
        <source>Could not open file for writing.</source>
        <translation type="obsolete">无法对文件进行读写.</translation>
    </message>
    <message>
        <location filename="../src/tiled/tmxmapreader.h" line="+55"/>
        <location filename="../src/tiled/tmxmapwriter.h" line="+56"/>
        <source>Tiled map files (*.tmx)</source>
        <translation>Tiled 地图文件 (*.tmx)</translation>
    </message>
</context>
<context>
    <name>TmxReader</name>
    <message>
        <source>Not a map file.</source>
        <translation type="obsolete">该地图的文件不可用.</translation>
    </message>
    <message>
        <source>Not a tileset file.</source>
        <translation type="obsolete">该图块的文件不可用.</translation>
    </message>
    <message>
        <source>%3

Line %1, column %2</source>
        <translation type="obsolete">%3

行 %1, 位置 %2</translation>
    </message>
    <message>
        <source>File not found: %1</source>
        <translation type="obsolete">文件没有找到: %1</translation>
    </message>
    <message>
        <source>Unable to read file: %1</source>
        <translation type="obsolete">无法读取文件: %1</translation>
    </message>
    <message>
        <source>Unsupported map orientation: &quot;%1&quot;</source>
        <translation type="obsolete">地图不支持旋转: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
        <translation type="obsolete">无效的图块属性&apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error while loading tileset &apos;%1&apos;: %2</source>
        <translation type="obsolete">载入图块错误 &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <source>Invalid tile ID: %1</source>
        <translation type="obsolete">无效块ID: %1</translation>
    </message>
    <message>
        <source>Error loading tileset image:
&apos;%1&apos;</source>
        <translation type="obsolete">载入图块图像出错:
&apos;%1&apos;</translation>
    </message>
    <message>
        <source>Too many &lt;tile&gt; elements</source>
        <translation type="obsolete">&lt;块&gt; 元素过多</translation>
    </message>
    <message>
        <source>Invalid tile: %1</source>
        <translation type="obsolete">无效块: %1</translation>
    </message>
    <message>
        <source>Unknown encoding: %1</source>
        <translation type="obsolete">未知编码: %1</translation>
    </message>
    <message>
        <source>Compression method &apos;%1&apos; not supported</source>
        <translation type="obsolete">不支持压缩方式&apos;%1&apos;</translation>
    </message>
    <message>
        <source>Corrupt layer data for layer &apos;%1&apos;</source>
        <translation type="obsolete">图层 &apos;%1&apos; 数据已损坏</translation>
    </message>
    <message>
        <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
        <translation type="obsolete">无法解析块在（%1，%2层）&apos;%3&apos;</translation>
    </message>
    <message>
        <source>Invalid global tile id (less than 0): %1</source>
        <translation type="obsolete">无效的全局块id(小于0): %1</translation>
    </message>
    <message>
        <source>Tile used but no tilesets specified</source>
        <translation type="obsolete">没有指定图块</translation>
    </message>
</context>
<context>
    <name>TmxViewer</name>
    <message>
        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+160"/>
        <source>TMX Viewer</source>
        <translation>TMX查看器</translation>
    </message>
</context>
<context>
    <name>Undo Commands</name>
    <message>
        <location filename="../src/tiled/addremovelayer.h" line="+67"/>
        <source>Add Layer</source>
        <translation>添加图层</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Remove Layer</source>
        <translation>删除图层</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovemapobject.cpp" line="+79"/>
        <source>Add Object</source>
        <translation>添加对象</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Remove Object</source>
        <translation>删除对象</translation>
    </message>
    <message>
        <location filename="../src/tiled/changemapobject.cpp" line="+35"/>
        <source>Change Object</source>
        <translation>修改对象</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeobjectgroupproperties.cpp" line="+37"/>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+21"/>
        <source>Change Object Layer Properties</source>
        <translation>修改对象层属性</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeproperties.cpp" line="+34"/>
        <source>Change %1 Properties</source>
        <translation>%1 属性修改</translation>
    </message>
    <message>
        <location filename="../src/tiled/changetileselection.cpp" line="+31"/>
        <source>Change Selection</source>
        <translation>更改选择</translation>
    </message>
    <message>
        <location filename="../src/tiled/erasetiles.cpp" line="+39"/>
        <source>Erase</source>
        <translation>清除</translation>
    </message>
    <message>
        <location filename="../src/tiled/filltiles.cpp" line="+36"/>
        <source>Fill Area</source>
        <translation>填充</translation>
    </message>
    <message>
        <source>Move Layer Down</source>
        <translation type="obsolete">下移图层</translation>
    </message>
    <message>
        <source>Move Layer Up</source>
        <translation type="obsolete">上移图层</translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobject.cpp" line="+39"/>
        <source>Move Object</source>
        <translation>移动对象</translation>
    </message>
    <message>
        <location filename="../src/tiled/offsetlayer.cpp" line="+40"/>
        <source>Offset Layer</source>
        <translation>挪动图层</translation>
    </message>
    <message>
        <location filename="../src/tiled/painttilelayer.cpp" line="+49"/>
        <source>Paint</source>
        <translation>绘画</translation>
    </message>
    <message>
        <location filename="../src/tiled/renamelayer.cpp" line="+40"/>
        <source>Rename Layer</source>
        <translation>修改图层名称</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizelayer.cpp" line="+37"/>
        <source>Resize Layer</source>
        <translation>调整图层大小</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemap.cpp" line="+32"/>
        <source>Resize Map</source>
        <translation>调整地图大小</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemapobject.cpp" line="+39"/>
        <source>Resize Object</source>
        <translation>调整对象大小</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.cpp" line="+62"/>
        <source>Add Tileset</source>
        <translation>添加图块</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.h" line="+78"/>
        <source>Remove Tileset</source>
        <translation>删除 Tileset</translation>
    </message>
    <message>
        <location filename="../src/tiled/movetileset.cpp" line="+31"/>
        <source>Move Tileset</source>
        <translation>移动图块</translation>
    </message>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="-159"/>
        <source>Import Tileset</source>
        <translation>导入图块</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Export Tileset</source>
        <translation>导出图块</translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobjecttogroup.cpp" line="+40"/>
        <source>Move Object to Layer</source>
        <translation>移动对象到层</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeimagelayerproperties.cpp" line="+39"/>
        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+28"/>
        <source>Change Image Layer Properties</source>
        <translation>改变图像图层属性</translation>
    </message>
    <message>
        <location filename="../src/tiled/movelayer.cpp" line="+37"/>
        <source>Lower Layer</source>
        <translation>后置图层</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Raise Layer</source>
        <translation>前置图层</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/tiled/utils.cpp" line="+31"/>
        <source>Image files</source>
        <translation>图像文件</translation>
    </message>
</context>
</TS>
